@@ -63,7 +63,7 @@ class PipelineOperator:
                 token = ""
                 if 'sv=' in conn_str:
                     token = conn_str[conn_str.index('sv='):]
-                conn_str = f"BlobEndPoint={storage_url};QueueEndPoint={storage_url};FileEndPoint={storage_url};TableEndPoint={storage_url};SharedAccessSignature="
+                conn_str = f"BlobEndPoint={storage_url};QueueEndPoint={storage_url.replace('.blob.', '.queue.')};FileEndPoint={storage_url.replace('.blob.', '.file.')};TableEndPoint={storage_url.replace('.blob.', '.table.')};SharedAccessSignature="
                 self.logger.warning(
                     f"Detected an invalid connection string not matching the format:\n" +
                     f"<BlobEndpoint=https://contosostorageaccount.blob.core.windows.net/;QueueEndpoint=https://contosostorageaccount.queue.core.windows.net/;FileEndpoint=https://contosostorageaccount.file.core.windows.net/;TableEndpoint=https://contosostorageaccount.table.core.windows.net/;SharedAccessSignature=sv=...>" +
@@ -80,7 +80,7 @@ if __name__ == '__main__':
     """
     parser = argparse.ArgumentParser()
     parser.add_argument('--conn_str', type=str, required=True, help="Azure Storage Container connection string in the format: <BlobEndpoint=https://contosostorageaccount.blob.core.windows.net/;QueueEndpoint=https://contosostorageaccount.queue.core.windows.net/;FileEndpoint=https://contosostorageaccount.file.core.windows.net/;TableEndpoint=https://contosostorageaccount.table.core.windows.net/;SharedAccessSignature=sv=...>")
-    parser.add_argument('--storage_url', type=str, required=True)
+    parser.add_argument('--storage_url', type=str, required=True, help="URL for the blob storage container specified")
     parser.add_argument('--container_name', type=str, required=True)
     parser.add_argument('--map_name', type=str, required=False,
                         default=f"storage_map_{datetime.now().strftime('%Y_%m')}.json")
